#
# spec file for package kf6-ktexteditor
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.6.0

%define rname ktexteditor
# Full KF6 version (e.g. 6.3.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-ktexteditor
Version:        6.3.0
Release:        1.1
Summary:        Embeddable text editor component
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(EditorConfig)
BuildRequires:  cmake(KF6Archive) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Config) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6I18n) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6KIO) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Parts) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Sonnet) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6SyntaxHighlighting) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6TextToSpeech) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}
BuildRequires:  pkgconfig(libgit2)
Requires:       kf6-syntax-highlighting >= %{_kf6_bugfix_version}

%description
KTextEditor provides a text editor component that can be embedded in
applications, either as a KPart or using the KF6::TextEditor library.

%package -n libKF6TextEditor6
Summary:        Embeddable text editor component
Requires:       kf6-ktexteditor >= %{version}

%description -n libKF6TextEditor6
KTextEditor provides a text editor component that can be embedded in
applications, either as a KPart or using the KF6::TextEditor library.

%package devel
Summary:        Header files for ktexteditor, an embeddable text editor component
Requires:       libKF6TextEditor6 = %{version}
Requires:       cmake(KF6Parts) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6SyntaxHighlighting) >= %{_kf6_bugfix_version}

%description devel
KTextEditor provides a text editor component that can be embedded in
applications, either as a KPart or using the KF6::TextEditor library.

This subpackage provides the header files.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE \
           -DENABLE_KAUTH:BOOL=FALSE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang ktexteditor6

%ldconfig_scriptlets -n libKF6TextEditor6

%files
%{_kf6_debugdir}/ktexteditor.categories
%{_kf6_debugdir}/ktexteditor.renamecategories
# TODO split
%dir %{_kf6_plugindir}/kf6/parts
%{_kf6_plugindir}/kf6/parts/katepart.so

%files -n libKF6TextEditor6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6TextEditor.so.*

%files devel
%doc %{_kf6_qchdir}/KF6TextEditor.*
%{_kf6_cmakedir}/KF6TextEditor/
%{_kf6_includedir}/KTextEditor/
%{_kf6_libdir}/libKF6TextEditor.so
%{_kf6_sharedir}/kdevappwizard/templates/ktexteditor6-plugin.tar.bz2

%files -n kf6-ktexteditor-lang -f ktexteditor6.lang

%changelog
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * ensure the color name text is visible (kde#487068)
  * ensure we not reset the dynamic word wrap state (kde#487216)
  * Port to KStandardActions
  * Never remove trailing spaces on diff file type
  * Remove explicit maintainer from metainfo
  * Screenshot dialog: support drag of image
  * make tests independent of the user's environment
  * Modernize use designated init
  * do not display diff result in script tests when -silent is used
  * fix raw string indentation with cstyle + C++
  * Use ellipsis character instead of three dots in UI strings
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * Fix caret painting for inline notes at the end of line
  * KateCompletionWidget: Mark function static
  * KateCompletionModel: remove useless std::as_const
  * run more tests offscreen
  * Fix performance with many cursors in a large line
  * fix test expectations
  * fix crashs and OOM on load with encoding failures (kde#486195)
  * a11y: Improve tab order for "Appeareance" -> "Borders"
  * a11y: Set "Line Height Multiplier" buddy
  * Fix broken navigation in completion widget with multiple views
  * Fix clicking in completion
  * fix textInsertedRange signal for insertText behind last line (kde#483363)
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * Fix argument hint placement
  * Dont use activeView as save dialog parent (kde#484466)
  * ensure only set stuff is saved
  * Dont write useless entries to session config
  * all tests work offscreen in the CI
  * try to avoid crash in destructor
  * try more offscreen
  * ensure we don't crash if no view is active
  * kateviewinternal: accept surrogate category character (kde#482864)
  * use test mode with e.g. own temporary config files
  * avoid using QChar constructor for key codes (kde#483631)
  * remove obsolete option code
  * Remove focus frame option (kde#483218)
  * Fix duplicate folds occuring
  * Fix support for folding in vi normal mode
  * adapt test to hinting change
  * Set full hinting instead to ensure the letters are aligned properly (kde#482659)
  * try to save changes
  * Optimize a mark-restoring condition after document reload
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * add setRange overloads
  * be consistent, the wrapper never uses const to hand out refs/pointers
  * update version for new release
  * Include QWidgetList
  * add widgets api
  * ensure we support unicode in patterns (kde#462437)
  * fix quadratic checks
  * fix handling for full scanned lines
  * split lines early (kde#479073)
  * more line wrapping tests
  * Dont apply clipping with selections (kde#475378)
  * Fix selection rendering with custom line height (kde#475378)
  * Plugin template: fix plugin installation path
  * Plugin template: bump min KF dep to match initial KF6 release
  * Fix dyn word wrap indicator validation check (kde#480831)
  * util-scripts: Use setText when working with whole document
  * fix formatting
  * check longestLineLoaded, too
  * add test for setLineLengthLimit
  * use cursorToOffset for accessibility events
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-ktexteditor
